R/score_aggregation.R
first_score_only.RdThis function enables comparison of the results of two scoring functions by just basing the decision on the first element. This reflects the original behavior of the optimization function, just evaluating the 'auxiliary' scores for the user's information.
first_score_only(scores, ...)The aggregated score, i.e. the first element of a multiple-component score vector.
first_score_only(c(1, 2, 3))
#> [1] 1